@@ -31,7 +31,9 @@
  * @Short_description: An extension of GtkApplicationWindow
  * @Title: AmtkApplicationWindow
  *
- * #AmtkApplicationWindow extends the #GtkApplicationWindow class.
+ * #AmtkApplicationWindow extends the #GtkApplicationWindow class with a
+ * #AmtkApplicationWindow:statusbar property and functions to show longer
+ * descriptions of #GtkMenuItem's to the #GtkStatusbar.
  *
  * Note that #AmtkApplicationWindow extends the #GtkApplicationWindow class but
  * without subclassing it, because several libraries might want to extend
@@ -39,6 +41,22 @@
  * extensions at the same time.
  */
 
+/* API design:
+ *
+ * AmtkApplicationWindow was first implemented in Tepl, and
+ * TeplApplicationWindow needs to access the GtkApplicationWindow for the
+ * GActionMap. Currently AmtkApplicationWindow could be renamed to AmtkWindow
+ * and be an extension of GtkWindow instead of GtkApplicationWindow, it would
+ * have the advantage to have shorter function names and be a little more
+ * re-usable. But I think it's not a big problem to keep AmtkApplicationWindow
+ * as is, because (1) the A in Amtk is all about GActions, so normally the app
+ * already uses GtkApplicationWindow, (2) it is easy to port an application to
+ * use GtkApplicationWindow, most of the time it's just changing the parent
+ * class when subclassing GtkWindow, (3) it is more future-proof for Amtk to
+ * have access to the GtkApplicationWindow, in case we want to add some features
+ * that require the GActionMap or whatever. -- swilmet
+ */
+
 struct _AmtkApplicationWindowPrivate
 {
 	GtkApplicationWindow *gtk_window;
@@ -453,8 +471,7 @@ statusbar_notify_cb (AmtkApplicationWindow *amtk_window,
  *
  * The long description is retrieved with amtk_menu_item_get_long_description().
  * So amtk_menu_item_set_long_description() must have been called, which is the
- * case if the #GtkMenuItem has been created with the functions available in
- * #AmtkActionInfoStore.
+ * case if the #GtkMenuItem has been created with #AmtkFactory.
  *
  * Since: 2.0
  */
@@ -536,11 +553,10 @@ open_recent_file_cb (GtkRecentChooser *recent_chooser,
 }
 
 /**
- * amtk_application_window_create_open_recent_menu_item:
+ * amtk_application_window_create_open_recent_menu:
  * @amtk_window: an #AmtkApplicationWindow.
  *
- * Creates a #GtkMenuItem with a simple and generic #GtkRecentChooserMenu as
- * submenu.
+ * Creates a simple and generic #GtkRecentChooserMenu.
  *
  * The #GtkRecentChooser is configured to show files only recently used with the
  * current application, as returned by g_get_application_name(). If recent files
@@ -555,30 +571,19 @@ open_recent_file_cb (GtkRecentChooser *recent_chooser,
  * g_application_open() is called (with an empty hint), so the #GApplication
  * must have the %G_APPLICATION_HANDLES_OPEN flag set.
  *
- * Returns: (transfer floating): a new #GtkMenuItem.
- * Since: 2.0
+ * Returns: (transfer floating): a new #GtkRecentChooserMenu.
+ * Since: 3.0
  */
 GtkWidget *
-amtk_application_window_create_open_recent_menu_item (AmtkApplicationWindow *amtk_window)
+amtk_application_window_create_open_recent_menu (AmtkApplicationWindow *amtk_window)
 {
-	GtkMenuItem *menu_item;
-	gchar *long_description;
 	GtkRecentChooserMenu *recent_chooser_menu;
 	GtkRecentChooser *recent_chooser;
 	GtkRecentFilter *filter;
 
 	g_return_val_if_fail (AMTK_IS_APPLICATION_WINDOW (amtk_window), NULL);
 
-	menu_item = GTK_MENU_ITEM (gtk_menu_item_new_with_mnemonic (_("Open _Recent")));
-
-	/* Translators: %s is the application name. */
-	long_description = g_strdup_printf (_("Open a file recently used with %s"),
-					    g_get_application_name ());
-	amtk_menu_item_set_long_description (menu_item, long_description);
-	g_free (long_description);
-
 	recent_chooser_menu = GTK_RECENT_CHOOSER_MENU (gtk_recent_chooser_menu_new ());
-	gtk_menu_item_set_submenu (menu_item, GTK_WIDGET (recent_chooser_menu));
 
 	recent_chooser = GTK_RECENT_CHOOSER (recent_chooser_menu);
 	gtk_recent_chooser_set_local_only (recent_chooser, FALSE);
@@ -596,6 +601,40 @@ amtk_application_window_create_open_recent_menu_item (AmtkApplicationWindow *amt
 				 amtk_window,
 				 0);
 
+	return GTK_WIDGET (recent_chooser_menu);
+}
+
+/**
+ * amtk_application_window_create_open_recent_menu_item:
+ * @amtk_window: an #AmtkApplicationWindow.
+ *
+ * Creates a #GtkMenuItem with a simple and generic #GtkRecentChooserMenu as
+ * submenu. The #GtkRecentChooserMenu is created with
+ * amtk_application_window_create_open_recent_menu().
+ *
+ * Returns: (transfer floating): a new #GtkMenuItem.
+ * Since: 2.0
+ */
+GtkWidget *
+amtk_application_window_create_open_recent_menu_item (AmtkApplicationWindow *amtk_window)
+{
+	GtkMenuItem *menu_item;
+	gchar *long_description;
+	GtkWidget *recent_chooser_menu;
+
+	g_return_val_if_fail (AMTK_IS_APPLICATION_WINDOW (amtk_window), NULL);
+
+	menu_item = GTK_MENU_ITEM (gtk_menu_item_new_with_mnemonic (_("Open _Recent")));
+
+	/* Translators: %s is the application name. */
+	long_description = g_strdup_printf (_("Open a file recently used with %s"),
+					    g_get_application_name ());
+	amtk_menu_item_set_long_description (menu_item, long_description);
+	g_free (long_description);
+
+	recent_chooser_menu = amtk_application_window_create_open_recent_menu (amtk_window);
+	gtk_menu_item_set_submenu (menu_item, recent_chooser_menu);
+
 	return GTK_WIDGET (menu_item);
 }
 
