@@ -24,10 +24,15 @@
 #error "Only <tepl/tepl.h> can be included directly."
 #endif
 
-#include <gio/gio.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
+/* String utilities */
+
+gchar *		_tepl_utils_str_middle_truncate			(const gchar *str,
+								 guint        truncate_length);
+
 /* File utilities */
 
 G_GNUC_INTERNAL
@@ -44,6 +49,10 @@ gboolean	_tepl_utils_decode_uri				(const gchar  *uri,
 G_GNUC_INTERNAL
 gchar *		_tepl_utils_get_fallback_basename_for_display	(GFile *location);
 
+/* Widget utilities */
+
+GtkWidget *	_tepl_utils_create_close_button			(void);
+
 G_END_DECLS
 
 #endif /* TEPL_UTILS_H */
